/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.BorderLayout;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.geoviewer.render.GeometricalPreviewPanel;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;
import org.openide.windows.TopComponent;

/**
 * Visual tab for CropFields
 * @author Gerben Feenstra
 */
@MultiViewElement.Registration(displayName = "#LBL_CropField_VISUAL",
iconBase = "nl/cloudfarming/client/productionunit/draw_island16.png",
mimeType = CropField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "CropFieldVisual",
position = 2000)
@Messages(value={
    "LBL_CropField_VISUAL=Visual",
    "Title_CropField_VISUAL=Crop field visual preview"
})
public final class CropFieldVisualElement extends JPanel implements MultiViewElement, HelpCtx.Provider {

//    private CropFieldDataObject cropFieldDataObject;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private final Lookup lkp;

    public CropFieldVisualElement(Lookup lkp) {
        this.lkp = lkp;
        CropField cropField = lkp.lookup(CropField.class);
        assert cropField != null:" lookup should contain a CropField Object";
        
        this.setLayout(new BorderLayout());
        ASBodyPanel contentPanel = new ASBodyPanel(new GeometricalPreviewPanel(cropField));
        contentPanel.setTitle(Bundle.Title_CropField_VISUAL());
        contentPanel.setIcon(ImageUtilities.loadImageIcon("nl/cloudfarming/client/productionunit/draw_island32.png", true));
        add(contentPanel);
    }

    @Override
    public String getName() {
        return "CropFieldVisualElement";
    }

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lkp;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            CropField cropField = getLookup().lookup(CropField.class);
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(cropField.getName());
            tc.setDisplayName(cropField.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.cropfield.type.about");
    } 
}
