/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import javax.swing.JTextField;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.util.swing.FormRow;
import nl.cloudfarming.client.util.swing.beanbinding.DoubleConverter;
import org.jdesktop.beansbinding.AutoBinding;
import org.jdesktop.beansbinding.BeanProperty;
import org.jdesktop.beansbinding.BindingGroup;
import org.jdesktop.beansbinding.Bindings;
import org.openide.explorer.propertysheet.PropertyPanel;
import org.openide.nodes.Node;
import org.openide.nodes.PropertySupport;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle;

/**
 * Overview panel for {@link CropProductionUnit} 's
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 * @author Wytse Visser
 * @author Merijn Zengers
 */
@NbBundle.Messages({
    "CropProductionUnitDataPanel color label text=Color:",
    "CropProductionUnitDataPanel actual area label text=Actual area in HA:"})
public class CropProductionUnitDataPanel extends CropProductionUnitDetailsPanel {
    public static final int MAX_FRACTIONS_AREA = 2;

    private PropertyPanel colorPicker;
    private final CropProductionUnit cropProductionUnit;
    Node.Property colorProp;
    private BindingGroup cropProductionUnitBindingGroup = new BindingGroup();
    private BeanProperty fieldPropActualArea = BeanProperty.create(CropProductionUnit.PROP_ACTUAL_AREA_IN_HECTARES);
    private BeanProperty formPropActualArea = BeanProperty.create("text");
    private JTextField actualAreaField = new JTextField();

    public CropProductionUnitDataPanel(CropProductionUnit cropProductionUnit) {
        super(cropProductionUnit);
        this.cropProductionUnit = cropProductionUnit;
        initComponents();
        bind();
    }

    private void initComponents() {
        actualAreaField.setEditable(false);
        add(new FormRow(false, Bundle.CropProductionUnitDataPanel_actual_area_label_text(), Bundle.CropProductionUnitDataPanel_actual_area_label_text(), actualAreaField));
        cropProductionUnit.addPropertyChangeListener(CropProductionUnit.PROP_COLOR, new ColorChangeListener());
        colorPicker = createPropertyPanel();
        add(new FormRow(false, Bundle.CropProductionUnitDataPanel_color_label_text(), Bundle.CropProductionUnitDataPanel_color_label_text(), colorPicker));
    }

    /**
     * bind form fields to CropProductionUnit properties
     */
    private void bind() {
        AutoBinding actualAreaBinding = Bindings.createAutoBinding(AutoBinding.UpdateStrategy.READ, cropProductionUnit, fieldPropActualArea, actualAreaField, formPropActualArea);
        actualAreaBinding.setConverter(new DoubleConverter(MAX_FRACTIONS_AREA));
        cropProductionUnitBindingGroup.addBinding(actualAreaBinding);
        cropProductionUnitBindingGroup.bind();
    }

    /**
     * Create the property panel for color selection
     *
     * @return
     */
    private PropertyPanel createPropertyPanel() {
        try {
            colorProp = new PropertySupport.Reflection(cropProductionUnit, Color.class, CropProductionUnit.PROP_COLOR);
            return new PropertyPanel(colorProp);
        } catch (NoSuchMethodException ex) {
            Exceptions.printStackTrace(ex);
        }
        return null;
    }

    /**
     * Get the selected color for the {@link CropProductionUnit}
     *
     * @return the selected {@link Color} or null if no Color is set
     */
    public Color getSelectedCropProductionUnitColor() {
        Object selectedColor = colorProp.getPropertyEditor().getValue();
        if (selectedColor instanceof Color) {
            return (Color) selectedColor;
        }
        return null;
    }

    /**
     * Set the color for the {@link CropProductionUnit}
     *
     * @param color The color to set
     */
    private void setSelectedCropProductionUnitColor(Color color) {
        colorProp.getPropertyEditor().setValue(color);
        colorPicker.repaint();
    }

    /**
     * Listener to changes in the color of the {@link CropProductionUnit}
     */
    private class ColorChangeListener implements PropertyChangeListener {

        @Override
        public void propertyChange(PropertyChangeEvent pce) {
            if (pce.getPropertyName().equals(CropProductionUnit.PROP_COLOR)) {
                setSelectedCropProductionUnitColor((Color) pce.getNewValue());
            }
        }
    }
}
