/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.farm.FarmProject;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@NodeFactory.Registration(projectType = FarmProject.PROJECT_TYPE)
public class CropProductionUnitRootNodeFactory implements NodeFactory {

    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.farm.productionunit");

    @Override
    public NodeList<?> createNodes(Project project) {
        List<Node> nodes = new ArrayList<>();

        nodes.add(new CropProductionUnitRootNode(getProductionUnitDirectoryNodeDelegate(project), project));

        return NodeFactorySupport.fixedNodeList(nodes.toArray(new Node[nodes.size()]));
    }

    private Node getProductionUnitDirectoryNodeDelegate(Project project) {
        FileObject productionUnitDir = project.getProjectDirectory().getFileObject(CropProductionUnitManagerImpl.CROP_PRODUCTION_UNIT_DIR);
        if (productionUnitDir == null) {
            try {
                productionUnitDir = project.getProjectDirectory().createFolder(CropProductionUnitManagerImpl.CROP_PRODUCTION_UNIT_DIR);
            } catch (IOException ex) {
                LOGGER.log(Level.WARNING, "Could not get production unit directory {0}", new Object[]{ex.getMessage()});
                return new AbstractNode(Children.LEAF);
            }
        }
        DataFolder productionUnitDataFolder = DataFolder.findFolder(productionUnitDir);
        return productionUnitDataFolder.getNodeDelegate();
    }
}
