/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit;

import java.awt.event.ActionEvent;
import java.util.List;
import javax.swing.AbstractAction;
import nl.cloudfarming.client.farm.model.CropField;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.farm.model.CropProductionUnitManager;
import nl.cloudfarming.client.util.actions.OpenCloseHandler;
import org.openide.awt.ActionID;
import org.openide.awt.ActionRegistration;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;

/**
 * Remove action for one or more {@link CropField}
 * Will ask the {@link OpenCloseHandler} to close the node
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 */
@ActionID(category = "Cropfield", id = "nl.cloudfarming.client.productionunit.RemoveCropfieldAction")
@ActionRegistration(displayName = "#RemoveCropfieldAction_action_name")
@NbBundle.Messages({"RemoveCropfieldAction_action_name=Remove cropfield"})
public class RemoveCropFieldAction extends AbstractAction {

    private List<Node> selectedNodes;

    public RemoveCropFieldAction(List<Node> selectedNodes) {
        super(Bundle.RemoveCropfieldAction_action_name());
        this.selectedNodes = selectedNodes;

    }

    @Override
    public void actionPerformed(ActionEvent e) {
        CropProductionUnitManager manager = Lookup.getDefault().lookup(CropProductionUnitManager.class);
        for (Node node : selectedNodes) {
            CropField cropField = node.getLookup().lookup(CropField.class);
            if (cropField != null) {
                CropProductionUnit cropProductionUnit = manager.find(cropField.getParentURI());
                if (cropProductionUnit != null) {
                    cropProductionUnit.removeCropField(cropField);
                }
                OpenCloseHandler.Event.triggerClose(node);
            }
        }
    }
}
