/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit.wizard;

import java.util.HashSet;
import java.util.Set;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.productionunit.CropProductionUnitDetailsController;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.HelpCtx;

/**
 * Controller for the {@link CropProductionUnitInputPanelVisual}
 *
 * @author Merijn Zengers
 */
public class CropProductionUnitInputPanel extends CropProductionUnitDetailsController implements WizardDescriptor.ValidatingPanel<WizardDescriptor> {

    private final Set<ChangeListener> listeners = new HashSet<>(1);
    private CropProductionUnit cropProductionUnit;

    public CropProductionUnitInputPanel(CropProductionUnit cropProductionUnit) {
        super(new CropProductionUnitInputPanelVisual(cropProductionUnit));
        this.cropProductionUnit = cropProductionUnit;

    }

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        return super.getComponent();
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx("help.key.here");
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.add(l);
        }
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
        synchronized (listeners) {
            listeners.remove(l);
        }
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty(CropProductionUnitWizardAction.CPU, cropProductionUnit);
    }

    @Override
    public void validate() throws WizardValidationException {
        if (!super.isPanelValid()) {
            super.validatePanel();
            //Put in empty message whe only want to stop advancing to the next panel 
            throw new WizardValidationException(getComponent(), "", "");
        }

    }
}
