/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit.wizard;

import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.farm.model.CropProductionUnit;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.openide.WizardDescriptor;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.NbBundle;

@NbBundle.Messages({
    "CropProductionUnitSummaryPanel_title=New production unit summary",
    "CropProductionUnitSummaryPanel_step_name=Input summary"
})
public class CropProductionUnitSummaryPanel implements WizardDescriptor.Panel<WizardDescriptor> {

    private ASBodyPanel component;
    private CropProductionUnitSummaryPanelVisual visualComponent;
    private static final String ICON = "nl/cloudfarming/client/productionunit/green32.png";

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public ASBodyPanel getComponent() {
        if (component == null) {
            visualComponent = new CropProductionUnitSummaryPanelVisual();
            component = new ASBodyPanel(visualComponent);
            component.setTitle(Bundle.CropProductionUnitSummaryPanel_title());
            component.setIcon(ImageUtilities.loadImageIcon(ICON, false));
            component.setName(Bundle.CropProductionUnitSummaryPanel_step_name());
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        return HelpCtx.DEFAULT_HELP;
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        if (wiz != null) {
            CropProductionUnit cpu = (CropProductionUnit) wiz.getProperty(CropProductionUnitWizardAction.CPU);
            visualComponent.setProductionUnitName(cpu.getName());
            visualComponent.setProductionUnitDescription(cpu.getDescription() != null ? cpu.getDescription() : "");
            visualComponent.setProductionUnitStartDate(cpu.getStartDate());
            visualComponent.setProductionUnitEndDate(cpu.getEndDate());
            visualComponent.setProductionUnitPlannedArea(cpu.getPlannedAreaInHectares());
            visualComponent.setProductionUnitCrop(cpu.getCrop());
            visualComponent.setProductionUnitClassification(cpu.getClassification());
            visualComponent.setProductionUnitVariety(cpu.getVariety());
        }
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
    }
}
