/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.productionunit.wizard;

import java.text.DateFormat;
import java.util.Date;
import javax.swing.JLabel;
import javax.swing.JPanel;
import net.miginfocom.swing.MigLayout;
import nl.cloudfarming.client.crop.model.Classification;
import nl.cloudfarming.client.crop.model.Crop;
import nl.cloudfarming.client.crop.model.Variety;
import org.openide.util.NbBundle;

@NbBundle.Messages({
    "CropProductionUnitSummaryPanelVisual summary label text=Please review the data you entered before pressing finish.",
    "CropProductionUnitSummaryPanelVisual production unit name label text=Production unit name:",
    "CropProductionUnitSummaryPanelVisual production unit description label text=Production unit description:",
    "CropProductionUnitSummaryPanelVisual production unit start date label text=Start date:",
    "CropProductionUnitSummaryPanelVisual production unit end date label text=End date:",
    "CropProductionUnitSummaryPanelVisual production unit crop label text=Crop:",
    "CropProductionUnitSummaryPanelVisual production unit classification label text=Classification:",
    "CropProductionUnitSummaryPanelVisual production unit variety label text=Variety:",
    "CropProductionUnitSummaryPanelVisual production unit planned area label text=Planned area in HA:"})
public final class CropProductionUnitSummaryPanelVisual extends JPanel {

    private JLabel summaryLabel;
    private JLabel productionUnitNameLabel;
    private JLabel productionUnitNameValueLabel;
    private JLabel productionUnitDescriptionLabel;
    private JLabel productionUnitDescriptionValueLabel;
    private JLabel productionUnitStartDateLabel;
    private JLabel productionUnitStartDateValueLabel;
    private JLabel productionUnitEndDateLabel;
    private JLabel productionUnitEndDateValueLabel;
    private JLabel productionUnitPlannedAreaLabel;
    private JLabel productionUnitPlannedAreaValueLabel;
    private JLabel productionUnitCropDefinitionLabel;
    private JLabel productionUnitCropDefinitionValueLabel;
    private JLabel productionUnitClassificationLabel;
    private JLabel productionUnitClassificationValueLabel;
    private JLabel productionUnitVarietyLabel;
    private JLabel productionUnitVarietyValueLabel;
    private DateFormat dateFormat = DateFormat.getDateInstance(DateFormat.MEDIUM);

    /**
     * Creates new form CropProductionUnitSummaryPanel
     */
    public CropProductionUnitSummaryPanelVisual() {
        init();
    }

    @Override
    public String getName() {
        return "Step #2";
    }

    private void init() {
        setLayout(new MigLayout("wrap 2"));
        productionUnitNameValueLabel = new JLabel();
        productionUnitDescriptionValueLabel = new JLabel();
        productionUnitStartDateValueLabel = new JLabel();
        productionUnitEndDateValueLabel = new JLabel();
        productionUnitPlannedAreaValueLabel = new JLabel();
        productionUnitCropDefinitionValueLabel = new JLabel();
        productionUnitClassificationValueLabel = new JLabel();
        productionUnitVarietyValueLabel = new JLabel();

        summaryLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_summary_label_text());
        productionUnitNameLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_name_label_text());
        productionUnitDescriptionLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_description_label_text());
        productionUnitStartDateLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_start_date_label_text());
        productionUnitEndDateLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_end_date_label_text());
        productionUnitPlannedAreaLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_planned_area_label_text());
        productionUnitCropDefinitionLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_crop_label_text());
        productionUnitClassificationLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_classification_label_text());
        productionUnitVarietyLabel = new JLabel(Bundle.CropProductionUnitSummaryPanelVisual_production_unit_variety_label_text());

        add(summaryLabel, "span 2");

        add(productionUnitNameLabel, "gaptop 40px");
        add(productionUnitNameValueLabel);

        add(productionUnitDescriptionLabel);
        add(productionUnitDescriptionValueLabel);

        add(productionUnitStartDateLabel);
        add(productionUnitStartDateValueLabel);

        add(productionUnitEndDateLabel);
        add(productionUnitEndDateValueLabel);

        add(productionUnitPlannedAreaLabel);
        add(productionUnitPlannedAreaValueLabel);

        add(productionUnitCropDefinitionLabel);
        add(productionUnitCropDefinitionValueLabel);

        add(productionUnitVarietyLabel);
        add(productionUnitVarietyValueLabel);

        add(productionUnitClassificationLabel);
        add(productionUnitClassificationValueLabel);
    }

    public void setProductionUnitName(String name) {
        productionUnitNameValueLabel.setText(name);
    }

    public void setProductionUnitDescription(String description) {
        productionUnitDescriptionValueLabel.setText(description);
    }

    public void setProductionUnitStartDate(Date startDate) {
        productionUnitStartDateValueLabel.setText(startDate != null ? dateFormat.format(startDate) : "");
    }

    public void setProductionUnitEndDate(Date endDate) {
        productionUnitEndDateValueLabel.setText(endDate != null ? dateFormat.format(endDate) : "");
    }

    /**
     * Set the planned area in ha
     *
     * @param area
     */
    public void setProductionUnitPlannedArea(Double area) {
        if (area != null) {
            productionUnitPlannedAreaValueLabel.setText(area.toString());
        }
    }

    public void setProductionUnitCrop(Crop crop) {
        productionUnitCropDefinitionValueLabel.setText(crop != null ? crop.getName() : "");
    }

    public void setProductionUnitClassification(Classification classification) {
        productionUnitClassificationValueLabel.setText(classification != null ? classification.getName() : "");
    }

    public void setProductionUnitVariety(Variety variety) {
        productionUnitVarietyValueLabel.setText(variety != null ? variety.getName() : "");
    }
}
